@@ -19,11 +19,10 @@ Usage::
     list_repository_associations_paginator: ListRepositoryAssociationsPaginator = client.get_paginator("list_repository_associations")
     ```
 """
-from mypy_boto3_codeguru_reviewer.client import (
-    CodeGuruReviewerClient,
-    CodeGuruReviewerClient as Client,
-)
+from mypy_boto3_codeguru_reviewer.client import CodeGuruReviewerClient
 from mypy_boto3_codeguru_reviewer.paginator import ListRepositoryAssociationsPaginator
 
+Client = CodeGuruReviewerClient
+
 
 __all__ = ("Client", "CodeGuruReviewerClient", "ListRepositoryAssociationsPaginator")
